bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 10. Aventiure
___________________________________________________ #### Auentv wie der kunec Gunther zu Wormze #### mit frov Prvnh' <prvtte>
| ### Anderthalp> des Rines sach man mit grozen scharn ### den chunic mit sinen gesten zv dem stade varn ### ovch sach man da bi zovmen leiten manige meit ### di si enpfahen solden die waren alle bereit ### Do die von Islande zen schiffen chomen dan ### vn– ovch von Nibelungen Sivrides man ### si gahten zv dem lande vnmvzich wart ir hant ### da man des chvniges frivnde des stades anderthalben vant
###### 587 | ### Nv hoert ovch disiv mære von der chvnegin ### Uten der vil richen wie si div mægedin ### gefrvmte von der bvrge dar si do selbe reit ### da gewan ein ander chvnde vil manic ritter vn– meit
| ### Der margrave Gere Chriemhilde zovmte dan ### niwan vz der burge Sivrit der chvne man ### dient ir do minnekliche si was ein schoene kint ### des wart im wol gelonet von der ivncfrowen sint
###### 589 | ### Ortwin der chvne bi fron Voten reit ### vil gesellechlichen manic ritter vn– meit ### ze solhem antphange des mach man wol veriehen ### wart nie so vil der frowen bi ein ander gesehn
###### 590 | ### Vil manic bvhvrt richen sach man dan getribn ### von helden loblichen niht wol wær ez beliben ### vor <Chriemhilde> der schoenen al zv den schiffen dan ### do hvop man von den moeren manige frowen wolgetan
###### 591 | ### Der chvnich was chomen selbe vn– manic werder gast ### hey was starcher schefte vor den frowen brast ### man hort da hvrteklichen von schilden manigen stoz ### hey waz da richer bvckelen von gedrange lvot erdoz
| ### Die vil minneklichen die stvnden an der habe ### Gunther mit sinen gesten gie von den schiffen abe ### er fvorte Prvnhilde selbe an siner hant ### da lvhten wider ein ander die edeln <stein> vn– ovch daz gewant
###### 593 | ### In vil grozen zvhren frow Chriemh' do gie ### da si Prvnhilde mit ir gesinde enpfie ### da wart gervchet hoher mit wnneklicher hant ### vil manic schapel riche do si sie enpfiengen in daz lant
###### 594 | ### Do sprach gezogenliche Chriemh' div chvniginne ### ir svlt zv disen landen groz willechomen sin ### mir vn– miner mvoter vnde allen die wir <han> ### dar nach wart von den vrowen mit trvten chvssen niht verlan
###### 595 | ### Do Prvnh' frowen vol chomen vf den sant ### da wart vil minneklichen genomen bi der hant ### von herlichen rechen manich wip wol getan ### man sah die schonen megede vor den chvniginnen stan
###### 596 | ### E daz ir grvoz ergienge [23r]das was ein langiv stvnt ### ia wart da gechvsset manic rosen varwer mvont ### noh stvnden bi ein ander die kuniges tohter rich ### daz liebet an ze sehene vil manigen rechen lobelich
| ### Do speheten mit den ovgen die ê horten iehn ### daz si so minnechliches heten niht gesehn ### so die frowen beide des iach da manic man ### daz si den pris an schoene in manigen landen mvsen han
###### 598 | ### Die frowen spehen chvnden vn– herlichen lip ### die lobten durch ir schoene daz Guntheres wip ### doch sprachen da di wisen die hetenz baz ersehn ### man mohte Chriemh' wol fvr <Prvnhilde> iehn
###### 599 | ### Wider ein ander giengen beide magt vn– wip ### man sach da wol gezieret vil manigen schonen lip ### da warn sidin hutten vn– manich rich gezelt ### der was da vil gespannen vor Wormez vber al daz velt
###### 600 | ### Von des chuniges mâgen wart dringen niht verlan ### man hiez die chuniginne beide dannen gan ### vn– mit in al die frowen da man den scaten vant ### dar brahten si die degene vzer Burgonden lant
| ### Dv waren ovch die geste zen rossen alle chomen ### vil manic richiv tioste durch schilde wart genomen ### daz velt begunde stovben sam ob al daz lant ### mit lovge enbrunnen wære da wrden degene bechant
###### 602 | ### Wes da die helde pflægen daz sach vil manic meit ### man sagt <daz> her Sivrit mit sinen helden reit ### manige widerchere fvr die hutten dan ### er fvrt der Nibelunge tvsint wætlicher man
###### 603 | ### Do chom von Tronege Hagene als im der wirt geriet ### den bvhvrt frivntliche do der helt geschiet ### daz si ungestovbet liezen div <minneklichen> kint ### des wart do von den gesten gevolget zvhtekliche sint
###### 604 | ### Do sprach der herre Gernot div ross nv lazet stan ### vnz ez beginne chvolen so svlen wir ane van ### dienen schoenen wiben fvr den palas wit ### so der chunic welle riten daz ir bereite denne sit
###### 605 | ### Vor der <vesperzite> do div sunne nider gie ### vn– ez begunde chvolen niht langer man daz lie ### in die stat sich hvben man <magt> vn– wip ### mit ovgen wart getrvtet vil maniger ivncfrowen lip
###### 606 | ### Da wart von gvten rechen vil chleider ab gerieten ### von den hochgemvten nach ir lande siten ### vnz fvr den palas witen der chunich da nider stvnt ### da wart gedienet frowen so helde hoch gemvote tvont
| ### Do wrden ovch gescheiden die richen kunigin ### froe Vote vn– ovch ir tohter die giengen beide hin ### vn– mit ir ingesinde in ein vil witez gadem ### do hort man allenthalben vil harte grozlichen chradem
###### 608 | ### Gerihtet wart gesidele der chunic wolde gan ### ze tische mit den gesten do sach man bi im stan ### die schonen Prvnhilden chrone si do trvoch ### in des <chvniges> lande div was spæhe vn– rich genvoch
###### 609 | ### Vil manic hergesidele mit gvo[23v]ten taveln breit ### vol spise wart gesezzet als vns daz ist geseit ### des si haben solden wie wenich des gebrast ### do sach man bi dem kunige vil manigen herlichen gast
###### 610 | ### Des wirtes kamerære in pechen goldes rot ### daz wazzer fvor trvogen des wære lvzzil not ### ob iv daz iemen seite daz man diente baz ### ze kuniges hochgeciten ich gelovbe mvliche daz
| ### E daz der vogt von Rine wazzer do genam ### do tet der herre Sivrit als im do gezam ### er mant in siner triwe wes er im veriach ### e daz er Prvnhilde da heim in Islande sach
###### 612 | ### Er sprach zvo dem chvnege ia swor mir iwer hant ### swenne daz frov Prvnh' chome in dizze lant ### ir gæbt mir iwer swester war sint die eide chomen ### ich han an iwer reise vil micheI arebeit genomen
###### 613 | ### Do sprach der chunic riche ir habt mich reht ermant ### iane sol niht meineide werden des min hant ### ich wilz iv helfen fvgen so ich beste chan ### do hiez man Chriemh' ze hove zv dem chvnige gan
###### 614 | ### Mit ir schonen meiden si chom fvr den sal ### do spranch von einer stiegen Giselher zetal ### do hiez er wider wenden ir schonen mægedin ### niwan min swester eine div sol mit vns ze hove sin
###### 615 | ### Do brahter <sine> swester da man den chunic vant ### da stvnden ritter edele von maniger fvrsten lant ### in dem sal enmitten hiez man si stille stan ### do was div frowe Prvnhilt an ir sedel nv gegan
###### 616 | ### Sine wesse niht der mære waz man da wolde tvon ### do sprach zv sinen magen der Danchrates svn ### helfet mir daz min swester Sivriden neme ze man ### do sprachens al geliche si mag in wol mit eren han
| ### Do sprach der chunic Gvnther la dirz niht wesn leit ### min vil liebiv swester vn– loese minen eit ### ich swor dich eime rechen vn– wirdet er din man ### so hastv minen willen mit grozen triwen getan
###### 618 | ### Do sprach div magt edele vil lieber brvder min ### irn svlt mich niht vlehen ia wil ich immer sin ### swie ir mir gebietet daz sol sin getan ### ich sol in loben gerne den ir mir herre gebt ze man
###### 619 | ### Von lieber ovgenweide wart Sivrides varwe rot ### ze dienest sich der meide do der reche boe ### man hiez si zvo ein ander in dem ringe stan ### vn– vragtes ob si wolde den vil wætlichen man
###### 620 | ### In magtlichen zvehten si schamte sich ein teil ### iedoch so was gelucke vn– Sivrides heil ### daz si in niht versprechen wolde da zehant ### ovch lobte si ze wibe der edel chunic von Niderlant
###### 621 | ### Do si in gelobte vn– ovch er die meit ### gvtlich vmbevahen daz was da vil bereit ### von Sivrides armen daz minnekliche chint ### nach siten wart gechvsset div schone chvniginne sint
| ### Sich teilte daz gesinde als schiere daz geschach ### an daz gegensidele man Sivride sach ### mit Chriemh' sizzen dar dient im manic man ### man sach die Nibelunge nach im an den sedel gan [24r]
###### 623 | ### Ovch was der wirt gesezzen vn– Prunh' div meit ### do sach si Chriemh' do wart ir nie so leit ### bi Sivride sizzen weinen si began ### ir vielen heize træhene vber liehtiv wange dan
###### 624 | ### Do sprach der wirt des landes waz ist iv frowe min ### daz ir so lazet trvben liehter ovgen schin ### ir mohtet sanfter lachen wan iv ist vndertan ### min lant vnde riche bvrege vn– manic wætlicher man
###### 625 | ### Ich mac wol balde weinen sprach div schone meit ### vmbe dine swester ist mir so grimme leit ### di sich ich sizzen nahn dem eigen holden din ### daz mvoz mich immer riwen vn– sol si also verstozen sin
| ### Do sprach der chunich Gvnther ir mvgt wol stille dagn ### ich wil iv zandern citen disiv mære sagn ### warvmbe ich mine swester dem rechen han gegebn ### ia mac si mit dem degene immer vroliche lebn
###### 627 | ### Si sprach mich iamert immer ir schoene vn– ovch ir zvht ### vn– wesse ich war ich solde ich hete gerne vluht ### daz ich iv nimmer wolde geligen nahen bi ### irn saget mir wa von Chriemh' div wine Sivrides si
###### 628 | ### Do sprach der chvnic riche ich tvonz iv wol bechant ### er hat als wol burge als ich vn– witiv lant ### daz wizzet sicherlichen er ist ein chunic rich ### des gan ich im ze minnen die schonen magt lobelich
###### 629 | ### Swaz ir der chunic sagete si hete trvbin mvot ### do gahete von den tisschen vil manic ritter gvot ### ir bvhurt wart so herte daz al div bvrch erdoz ### den wirt do bi den gesten da ze wesene verdroz
###### 630 | ### Er daht er læge sanfter der schonen frowen bi ### do was er des gedingen niht in hercen vri ### im mvese von ir minne ein hohez liep geschehen ### er begunde vrivntliche an die magt dicke sehen
| ### Ir ritterschaft die geste hiez man do ab lan ### der chvnic mit sime wibe ze bette wolde gan ### vor des sales stiegen die frowen schieden sich ### in zhten minnekliche als ich wol verwæne mich
###### 632 | ### Do chom ir ingesinde die sovmten sich des niht ### ir richen chamerære die brahten in div lieht ### sich teilten do die rechen der zweier kunige man ### do sach man vil der degene dan mit Sivride gan
###### 633 | ### Die herren chomen beide al da si solden ligen ### do gedaht ir ieslicher mit minnen an gesigen ### den minneklichen frowen daz trost in wol den mvot ### Sivrides kvrzewile div wart vil grozliche gvot
###### 634 | ### Do der herre Sivrit bi Chriemh' lach ### vn– er so minnekliche der iuncfrowen pflach ### mit sinen edeln minnen si wart im so der lip ### daz chvnde ovch <si> verdienen als ein tvgende riche wip
###### 635 | ### Ine sage iv niht mere wie er der frowen pflac ### nv horet ovch disiv mære wie Gunther gelach ### bi der sinen brvte der vil mære degen ### was vil diche sanfter bi andern frowen gelegn
| ### Daz volch was im entwichen frowen vn– man ### do wart div kemenate balde zv getan ### er wande er solde trvten ir minneklichen lip ### ez was noch vil [24v]vnnahen e daz si wrde sin wip
###### 637 | ### In sabenwizem hemede si an ein bette gie ### do daht der ritter edele nv han ihz allez hie ### des ich ie da gerte in allen minen tagn ### si mvos im dvrch ir schone von grozen schulden wol behagn
###### 638 | ### Div lieht begunder bergen div Guntheres hant ### do gie der chunic riche da er die frowen vant ### er leite sich ir nahen sin frevde div wart groz ### die vil minneklichen der helt mit armen vnbesloz
###### 639 | ### Minnekliche trvten des chvnder vil began ### ob im des div frowe gegunnet wolde han ### do zvrnde si so sere daz in gemvete daz ### er wande vinden frivnde do vander vintlichen haz
###### 640 | ### Si sprach ritter edele ir svltez lazen stan ### des ir da habt gedingen iane mages niht ergan ### ich wil noch magt beliben ir svlt wol wizzen daz ### vnz ich div rehten mære ervinde an allen dingen baz
| ### Do rang er nach ir minne daz was der frowen leit ### do greif nach eime gvrtel div herliche meit ### daz was ein starcher porte den si alle cite trvoch ### wie luzzil si dem kunige sines willen do vertrvoch
###### 642 | ### Die fveze vn– ovch die hende zesamne si im bant ### si trvge in zeinem nagele vn– hienge in an die want ### daz enchunder niht erwenden vil chreftich wart sin not ### ia het er von ir sterche vil nach gewnnen den tot
###### 643 | ### Do begvnde vlegen der meister wande sin ### nv loset min gebende vil edeliv kunigin ### ine trow iv frowe nimmer mit minnen an gesigen ### vn– sol ovh harte selten iv so nahen mer geligen
###### 644 | ### Sine rvchte <wie> im wære wande si vil sanfte lach ### dort mvoser allez hangen die naht vnz an den tach ### vnze daz der morgen dvrch div venster schein ### des kuniges kurcewile was die wile harte chlein
| ### Nv sagt mir her Gunther wer iv daz iht leit ### ob ivch gebvnden fvnden so sprach div schone meit ### die iwern kamerære von einer frowen hant ### do sprach der ritter <edele> daz wrde iv vbel bewant
###### 646 | ### Ovch hete ichs luzzel ere sprach der chvene man ### dvrch iwer selber zvhte so lat mich zvo ziv gan ### sit daz iv min minne sint so grimme leit ### iane sol ich nimmer rveren mit miner hant an iwer chleit
###### 647 | ### Do si daz gehorte zehant si in verlie ### wider an daz bette er zv der frowen gie ### er leite sich so verre daz er ir schone wat ### niht mohte gereichen des wolde ovch si do haben rat
###### 648 | ### Do chom ir ingesinde vn– brahten in div kleit ### der was in an dem morgen harte vil bereit ### swie man da gebarte trvrich was genvoch ### der edel wirt des landes swier des tages chrone trvoch
| ### Nach siten der si pflagen vnde man durch reht #begîe ### der chunic mit siner frowen niht langer daz enlie ### si chomen zv dem mvenster da man die messe sanch ### ovch chom der herre Sivrit sich hvop da grozlich gedranch
###### 650 | ### Nach chunichlichen eren <was> in dar bereit [25r] ### swaz si habn solden ir chrone vn– ovch ir gekleit ### do wrden si gewihet do daz was getan ### do sah mans alle viere vnder chrone lobeliche stan
###### 651 | ### Vil knappen swert da namen vier hundert oder baz ### den kunigen zen eren ir svlt gelovben daz ### sich hvop vil michel frevde in des kuniges lant ### man horte schefte bresten an der swertdegene hant
###### 652 | ### Do sazen in den venstern div schonen magedin ### si sahen vor in glesten vil maniges schildes schin ### do het sich gesundert der chunic von sinen man ### swes <ander> iemen pflæge man sah in trvrende stan
###### 653 | ### Im vn– Sivride vngeliche stvnt der mvot ### wol wesse sine swære der chune degn gvot ### do gienger zv dem kvnige vragen er began ### wie ist iv hint gelungen des wolt ich gerne chunde han
| ### Do sprach der wirt zem gaste ich chlag iv minen schaden ### ich han den vbeln tivfel heim ze hvs geladen ### do ich si wande minnen vil sere si mich bant ### si trvge mich zeime nagele vn– hie mich hohe an ein want
###### 655 | ### Da hienge ich angestlichen die naht vnz an den tac ### e daz si mich enbvnde vnsanfte si min pflac ### daz sol iv friwentliche vf genade sin gechleit ### do sprach der herre Sivrit daz ist mir grozliche leit
###### 656 | ### Des bringe ich ivch wol innen vn– lat irz ane nit ### ich schaffe daz si noch hint so nahen bi iv geleit ### so daz si ivch ir minne gesvmet nimmer mer ### der rede was do Gunther nach sinen arebeiten her
###### 657 | ### Nv schowe mine hende wie di geswollen sint ### die twanc si mir so sere als ob ich wære ein kint ### daz mir blvot zen nagelen allenthalben dranch ### ich het ze mime lebene harte chleinen gedanch
###### 658 | ### Do sprach der starche Sivrit dv maht noch wol genesn ### vns zwein ist vngeliche hinte gewesn ### mir ist din swester Chriemh' als min selbes lip ### ez mvz div frowe Prvnh' noch hinte werden din wip
| ### Ich chvom ze naht vil tovgen zer kemenate din ### in miner tarnkappen des soltv sicher sin ### so daz sich miner liste mach niemen wol verstan ### so heiz die kamerære zvo zir herbergen gan
###### 660 | ### So lesche ovch ich den kinden div lieht an der hant ### bi disem wortzeichen sol dir sin bechant ### daz ich bi dir si nahen ia twing ich dir din wip ### daz dv si hint minnest oder ich verlivse den lip
###### 661 | ### Ane daz dv iht trvttest sprach der chunic do ### die mine lieben frowen anders bin ich vro ### so tvo ir swaz dv wellest vn– næmstv ir den lip ### daz solde ich wol verchiesen si ist ein vngehivrez wip
###### 662 | ### Daz nim ich so sprach Sivrit vf die triwe min ### daz ich ir niht en minne div schoene swester din ### div ist mir vor in allen die ich noch ie gesach ### des frowete sich do Gvnther do daz Sivrit gesprach
| ### Da was von churzewile in gedrange not ### den bvhurt vn– schallen allez man verbot ### da die frowen sol[25v]den in den palas gan ### do hiezen die kamerære die lvte von dem wege stan
###### 664 | ### Von <rossen> vn– von lvten gerovmet was der hofe ### der frowen iesliche fvrt ein bisscofe ### do si vor den kunigen ze tische solden gan ### in volgte zv dem sidele vil manic reche wolgetan
###### 665 | ### Der chunic in gvtem wane bi sime wibe saz ### daz im gelobte Sivrit wol gedahter an daz ### der eine tac in dvhte wol drizzech tage lanc ### an Prvnh' minne stvnde im aller sin gedanc
###### 666 | ### Wander erbeite chvome daz man ze naht von tische gie ### die schonen Prvnhilde man do chomen lie ### vn– ovch Chriemh' si bede an ir gemach ### hey waz <man> chuner degene bi den schonen frowen sach
###### 667 | ### Sivrit vn– Chriemh' ie baz vn– baz ### durch liebe ein ander trvoten ir svlt gelovben daz ### swaz si im gedienen chvnde wie luzzil si des liez ### do mvs ovch <leisten> Sivrit alser Gunther gehiez
###### 668 | ### Er stal sich von den frowen vil tovgen chom er dan ### da er vil kamerære vant mit liehten stan ### div begunde leschen den chinden an der hant ### daz ez Sivrit wære daz wart do Gunther bechant
###### 669 | ### Wol wesser waz er wolde do hiez er dannen gan ### mægede vn– frowen do daz wart getan ### er besloz mit vlize selbe do die tvr ### starcher rigele zwene die warfer snelle der fvr
###### 670 | ### Div lieht verbarger schiere vnder die bettewat ### eines spils begunde des was do niht rat ### Sivrit der vil starche vn– ovch div schone meit ### daz was do dem chunige beide lieb vn– leit
###### 671 | ### Der helt sich leite nahen der iuncfrowen bi ### si sprach nv lat ez Gvnther als liep als iv daz si ### daz ir niht arebeite lidet alsam ê ### sit getet div frowe dem chunige Sifride we
###### 672 | ### Do hal er sine stimme daz er niht ensprach ### der kunic ez allez horte swie er sin niht ensach ### daz heimlicher dinge von <in> da niht geschach ### si heten an dem bette harte kleinen gemach
| ### Er gebarte sam ez wære Gunther der chunic rich ### er vmbesloz mit armen die magt lobelich ### si warfen vz dem bette dabi vf einen banch ### daz im sin hovbet lvote an eime scamel erchlanch
###### 674 | ### Wider vf mit chreftin spranch der vil snelle man ### er woldez baz versvochen do er des began ### daz ers im wolde twingin dem erz gelobet ê ### solch wer deheiner frowen wêin ich immer mer erge
###### 675 | ### Do er niht wolde erwinden div magt balde vf spranch ### irn svlt mir niht zefveren min <hemede> also blanch ### mit iwer groz vnfvge wandez ist mir leit ### des bringe ich ivch wol innen sprach do div minneklichiv meit
###### 676 | ### Mit ir vil starchen armen besloz si den degn ### do wolde si in gebvnden alsam den kunic legen ### daz si an ir bette mohte habn gemach ### daz er ir wat zerfverte div frowe ez grozliche rach
###### 677 | ### Waz half sine groziv sterche vn– ovch sin michel chraft ### si erzeigete wol dem [26r]degene ir libes meisterschaft ### si trvge in mit gewalte da wart ir ellen schin ### vn– trvchtin vngefvege zwischen der <wende> vn– einen schrin
###### 678 | ### Owe gedaht der reche sol ich nv minen lip ### von einer magt verliesen so mvgen elliv wip ### her nach immer mere hohe tragen den mvot ### so <versvochtet> ez vil mænegiv div ez svs nimmer getvot
| ### Do schamte sich vil sere der vil chuone man ### ob ir gelinge solde zvrnen er began ### mit vngefveger chrefte sazter sich <ir> wider ### er versvochtez angestlichen an der chvniginne sider
###### 680 | ### Swie vaste si vf im læge sin zorn in do twanch ### vn– ovch sin starchez ellen daz er an ir danch ### sich wider vf gerihte sin angest div was groz ### si taten in dem gademe her vn– dar vil manigen stoz
###### 681 | ### Ovch was der chunic Gvnther niht an angest gar ### er mvse dicke wenchen vor in her vn– dar ### si rungen also starche daz ez groz wnder was ### daz ir ieslichez vor dem andern <ie> genas
###### 682 | ### Den kunich mvete sere beidenthalp div not ### doch vorhter michels mere den Sivrides tot ### wande si het dem degene den lip nach benomen ### wan daz er niht getorste er were ze helfe im gerne chomen
###### 683 | ### Ja werte harte lange vnder in der strit ### doch braht er die frowen wider an daz bette sit ### swie vaste si sich werte ir wer wart ze ivngest chranch ### der chunic in sinen sorgen hete manigen gedanch
| ### Ez dvhte in harte lenge e daz er si betwanch ### si drucht im sine hende daz vz den nageln spranch ### daz blvot im von ir chreften daz was dem helede leit ### sit brahter an ein lovgen die vil herlichen meit
###### 685 | ### ir vngefvges willen des si e da iach ### der chunich iz allez horte swier doeh niht ensprach ### er drvchtes an daz bette daz si vil lvt erschre ### ir taten sine chrefte do vil grozlichen we
###### 686 | ### Do greif si nach dem porten da si den ligen vant ### vn– wold in da mit binden do wert ez so sin hant ### daz ir div lit erchrachten do verzagt ir lip ### des wart der strit gescheiden do wart si Gvntheres wip
| ### Si sprach kunic edele ir svlt mich lebn lan ### ez wirt vil wol versvenet swaz ich iv han getan ### ich gewer mich nimmer mere der edeln minne din ### wand ich han wol erfvnden daz dv chanst frowen meister sin
###### 688 | ### Sivrit der stvnt dannen ligen liez er die meit ### sam er von sinem libe ziehen wolt div chleit ### er nam ir e ein vingerlin von golde wol getan ### daz wolde got von himele daz er daz hete verlan
###### 689 | ### Dar zvo nam er ir gvrtel daz was ein porte gvot ### ine weiz ob er daz tæte dvrch sinen hohen mvot ### er gab ez sime wibe daz wart im sider leit ### do lagen bi ein ander Gunther vn– Prunh' div meit
###### 690 | ### Er pflag ir minnekliche als in daz beiden zam ### do mvste si verchiesen ir zorn vn– ovch ir scham ### von siner heinliche si wart ein luzzil bleich ### hey waz ir von der min[26v]ne ir vil grozen chrefte entweich
| ### Done was ovch si niht stercher dann ein ander wip ### er trvote vil minnekliche den ir vil schonen lip ### ob siz versvochte mere waz chvnde daz vervan ### daz het ir der kunic Gunther mit sinen minnen getan
###### 692 | ### Wie rehte minnekliche si im nahen lac ### mit vrivntlicher liebe vnze an den liehten tac ### ovch was der <herre> Sivrit nv hin wider gegan ### da warde wol enpfangen von einer frowen wolgetan
###### 693 | ### Er vnderstunt ir vrage der si doch hete mvot ### vn– hal siz harte lange der chune degn gvot ### diz chleinoet er ir da heime doch ze iungest gap ### daz frumte vil der degene mit samt im selben in daz grap
###### 694 | ### Der wirt wart an dem morgen verre baz gemvot ### denner da vor wære des wart div froewde gvot ### in allen sinen landen von manigem hohen man ### die er zv huse ladete den wart do dienste vil getan
| ### Div hochgecite do werte vnz an den zwelften tac ### daz in al der wile der scal da nie gelac ### von aller hande vrevden der iemen solde pflegen ### do wart des chuniges choste vil harte hohe gewegn
###### 696 | ### Des edeln wirtes mage als ez der kunic gebot ### si gaben richiv chleider dar zvo daz golt vil rot ### ross vn– dar zv silber vil manigem varnden man ### die gabe nemen wolden die schieden vrolichen dan
###### 697 | ### Sivrit der herre vzer Niderlant ### mit tvsint sinen rechen allez daz gewant ### daz si ze Rine brahten daz wart gar hin gegebn ### vn– ovch div ross mit sætelen si chunden miltekliche lebn
###### 698 | ### E man die richen gabe alle da verswanch ### die wider ze lande wolden die dvhte des ze lanch ### ezn wart nie geste mere baz gepflegn ### svs endet sich div hochgecit daz wolde Gunther der degen

<<< Übersicht <<< vorige Seite nächste Seite >>>